.. _install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the Load-balancer
service, code-named Octavia, on the controller node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
Identity Service, Image Service, Placement Service, Compute Service,
and Networking Service.

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 2

   install-ubuntu.rst
   install-amphorav2.rst
